# python-template

![build](https://github.com/LeConTesteur/python-template/actions/workflows/build.yml/badge.svg)


## Description


### Example



## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install python-template
```

## Usage



## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

## Tests

Run tests with tox command :

```bash
tox
tox -e testsacc
```